@@ -28,8 +28,19 @@ class TestDataLoader(unittest.TestCase):
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
-    def testOnce(self):
+    def testMask(self):
+        for i in tfkit.gen_mask.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'mask.csv')):
+            print(i)
 
+        maxlen = 100
+        for i in tfkit.gen_mask.loadMaskDataset(os.path.join(TestDataLoader.DATASET_DIR, 'mask.csv'),
+                                                pretrained_config='voidful/albert_chinese_tiny',
+                                                maxlen=maxlen):
+            print(i)
+            self.assertTrue(len(i['input']) == maxlen)
+            self.assertTrue(len(i['target']) == maxlen)
+
+    def testOnce(self):
         tokenizer = BertTokenizer.from_pretrained('bert-base-uncased')
         for i in tfkit.gen_once.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'gen_long.csv')):
             print(i)
@@ -45,10 +56,19 @@ class TestDataLoader(unittest.TestCase):
     def testOnebyone(self):
         tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
 
+        maxlen = 10
+        feature = tfkit.gen_onebyone.get_feature_from_data(tokenizer, maxlen, "go go go go go go go", '',
+                                                           tokenized_target=["hi"],
+                                                           reserved_len=3)[-1]
+        print(feature)
+        self.assertTrue(feature['start'] == maxlen - 3)  ## -reserved_len
+
+        maxlen = 100
         for i in tfkit.gen_onebyone.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
             print(i)
-        maxlen = 100
-        for likelihood in ['onebyone-neg', 'onebyone-pos', 'onebyone-both']:
+
+        for likelihood in ['onebyone', 'onebyone-neg', 'onebyone-pos', 'onebyone-both']:
+            # for likelihood in ['onebyone-both']:
             for i in tfkit.gen_onebyone.loadOneByOneDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
                                                             pretrained_config='voidful/albert_chinese_tiny',
                                                             maxlen=maxlen, likelihood=likelihood):
@@ -85,11 +105,13 @@ class TestDataLoader(unittest.TestCase):
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) < 512)
 
-        for i in tfkit.classifier.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv')):
+        for i in tfkit.classifier.get_data_from_file(
+                os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv')):
             print(i)
-        for i in tfkit.classifier.loadClassifierDataset(os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv'),
-                                                        pretrained='voidful/albert_chinese_small',
-                                                        maxlen=512):
+        for i in tfkit.classifier.loadClassifierDataset(
+                os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv'),
+                pretrained='voidful/albert_chinese_small',
+                maxlen=512):
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) < 512)
 
@@ -118,6 +140,7 @@ class TestDataLoader(unittest.TestCase):
         ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                     pretrained='voidful/albert_chinese_small',
                                     maxlen=512)
-        print(ds.__len__())
+        print("before increase_with_sampling", ds.__len__())
         ds.increase_with_sampling(12)
-        self.assertTrue(ds.__len__() == 14)
+        print("after increase_with_sampling", ds.__len__())
+        self.assertTrue(ds.__len__() == 12)
